#!/usr/bin/perl
# usage: burnoff.pl months/07 months/08
# or: burnoff.pl months/*
# Does two things:
# 1) makes burnoff.out, a file of column formatted data.
#    For days when 4AM had ceiling below
#    2000 ft at 4am, the time prior to that when ceiling first went below 4000
#     ft and also the subsequent time when ceiling rose above 4000 (a "burnoff")
#    are recorded togther with the 4AM (12Z) surface obs.
# 2) puts to monitor the data for the histograms showing the time of burnoff
# 

@files=@ARGV;
$thresh1=.05;
$thresh2=.025;
$ncloud=0;
$nclear=0;
$tcheck=4;
$early='';
$hourly=1;
$lasthr=23;
open OUT,">burnoff.out";
open LOG,">burnoff.log";
for $file (@files){
  print "$file\n";
  open IN,"<$file";
  while ($line=<IN>){
	chomp($line);
    @a=split /\s+/, $line;
    $last_hr=$hr;
    $last_hr=-1 if $last_hr==23;
    $hr=$a[3];
    $iclht=$a[11];
    print "$line\n" if $iclht=~m/\*/;
    if ($hr==0){
      $last_clear=-1;
      $hourly=1;
    }
    if ($hr>0 && $hr != $last_hr+1){
      $hourly=0;# unless $hr=$last_hr+1;
      $skips{$a[0]}++;
      $early='';
      print LOG $line,"\n"; 
    }
    if ($hr<$tcheck){
      $last_clear=$hr if $iclht<$thresh1;
    }
    if ($hr==$tcheck){
      if ($early){
         $burnhour=19 if $burnhour > 19;
         print OUT "$early $burnhour\n";
         $burnoff[$burnhour-$tcheck]++;
      }
      if ($iclht>=$thresh1){  # ceiling <= 2000 feet
        $cloudy=1;
        $ncloud++;
        $early=$line.' '.$last_clear;
        $burnhour=19;
        $early='' if $line=~m/\*/;
      }
      else{
        $early='';
        $cloudy=0;
        $nclear++;
      }
    }
    $early='' if $clht=~m/\*/;
    if ($cloudy && $hr>$tcheck && $hr < 19 && $iclht<=$thresh2 && $hourly){ # ceiling >= 4000 feet
      $burnhour=$hr;
      $cloudy=0;
    }
  }
}
print "cloudy at $tcheck AM=$ncloud clear at $tcheck AM=$nclear\n";
$sum=0;
print "table of $tcheck AM + hour, and cleared during preceeding hour:\n";
for ($n=1;$n<=15;$n++){
  $sum+=$burnoff[$n];
  print "$n $burnoff[$n]\n";
}
print "total burnoff events= $sum\n";

for $key (sort keys %skips){
  print LOG "$key $skips{$key} \n";
}
